.. _benchcell:

Benchmark cells
===============

The description of a benchmark cell is used to determine the spiking schedule of the cell and manipulate its
performance efficiency. This cell is mainly used by developers.

API
---

* :ref:`Python <pybenchcell>`
